==> kubernetes-model-core-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/NamespaceStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamespaceStatusFluent<A extends NamespaceStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,NamespaceCondition item);
  public A setToConditions(Integer index,NamespaceCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A addAllToConditions(Collection<NamespaceCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A removeAllFromConditions(Collection<NamespaceCondition> items);
  public A removeMatchingFromConditions(Predicate<NamespaceConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NamespaceCondition> getConditions();
  public List<NamespaceCondition> buildConditions();
  public NamespaceCondition buildCondition(Integer index);
  public NamespaceCondition buildFirstCondition();
  public NamespaceCondition buildLastCondition();
  public NamespaceCondition buildMatchingCondition(Predicate<NamespaceConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<NamespaceConditionBuilder> predicate);
  public A withConditions(List<NamespaceCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public NamespaceStatusFluent.ConditionsNested<A> addNewCondition();
  public NamespaceStatusFluent.ConditionsNested<A> addNewConditionLike(NamespaceCondition item);
  public NamespaceStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,NamespaceCondition item);
  public NamespaceStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public NamespaceStatusFluent.ConditionsNested<A> editFirstCondition();
  public NamespaceStatusFluent.ConditionsNested<A> editLastCondition();
  public NamespaceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<NamespaceConditionBuilder> predicate);
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,NamespaceConditionFluent<NamespaceStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/NamespaceStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamespaceStatusFluent<A extends NamespaceStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,NamespaceCondition item);
  public A setToConditions(int index,NamespaceCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A addAllToConditions(Collection<NamespaceCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... items);
  public A removeAllFromConditions(Collection<NamespaceCondition> items);
  public A removeMatchingFromConditions(Predicate<NamespaceConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<NamespaceCondition> getConditions();
  public List<NamespaceCondition> buildConditions();
  public NamespaceCondition buildCondition(int index);
  public NamespaceCondition buildFirstCondition();
  public NamespaceCondition buildLastCondition();
  public NamespaceCondition buildMatchingCondition(Predicate<NamespaceConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<NamespaceConditionBuilder> predicate);
  public A withConditions(List<NamespaceCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.NamespaceCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public NamespaceStatusFluent.ConditionsNested<A> addNewCondition();
  public NamespaceStatusFluent.ConditionsNested<A> addNewConditionLike(NamespaceCondition item);
  public NamespaceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,NamespaceCondition item);
  public NamespaceStatusFluent.ConditionsNested<A> editCondition(int index);
  public NamespaceStatusFluent.ConditionsNested<A> editFirstCondition();
  public NamespaceStatusFluent.ConditionsNested<A> editLastCondition();
  public NamespaceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<NamespaceConditionBuilder> predicate);
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends Nested<N>,NamespaceConditionFluent<NamespaceStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
